pub enum FoundryLocalError {
Native {
code: NativeErrorCode,
message: String,
},
LibraryLoad {
reason: String,
},
CommandExecution {
reason: String,
},
InvalidConfiguration {
reason: String,
},
ModelOperation {
reason: String,
},
HttpRequest(Error),
Serialization(Error),
Validation {
reason: String,
},
Io(Error),
Internal {
reason: String,
},
}Expand description
Errors that can occur when using the Foundry Local SDK.
Variants
Native
The native core library returned an error.
LibraryLoad
The native core library could not be loaded.
CommandExecution
A command executed against the native core returned an error.
InvalidConfiguration
The provided configuration is invalid.
ModelOperation
A model operation failed (load, unload, download, etc.).
HttpRequest(Error)
An HTTP request to the external service failed.
Serialization(Error)
Serialization or deserialization of JSON data failed.
Validation
A validation check on user-supplied input failed.
Io(Error)
An I/O error occurred.
Internal
An internal SDK error (e.g. poisoned lock).
Implementations
Sourceimpl FoundryLocalError
impl FoundryLocalError
Sourcepub fn native_code(&self) -> Option<NativeErrorCode>
pub fn native_code(&self) -> Option<NativeErrorCode>
Returns the native error code, if this error originated in the native library.
Sourcepub fn native_message(&self) -> Option<&str>
pub fn native_message(&self) -> Option<&str>
Returns the native error message, if this error originated in the native library.